"""Effects to run on numpy arrays to make data clearer."""

from . import crop, lens, select_channels, overlay, transform
